"""
URL configuration for app project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, re_path

from .item import views as item_views
from .user import views as user_views
from .page import views as page_views
from . import views

urlpatterns = [
    path("admin/", admin.site.urls),
    path('robots.txt', views.robots_txt, name='robots_txt'),
    path('sitemap.xml', views.sitemap_xml, name='sitemap_xml'),
    path('atom.xml', item_views.atom_xml, name='atom_xml'),
    path('telegram/', views.telegram, name='telegram'),
    path('login/', user_views.login, name='login'),
    path('logout/', user_views.logout, name='logout'),
    path('register/', user_views.register, name='register'),
    path('comment/publish/', item_views.publish_comment, name='publish-comment'),
    path('comment/', item_views.comment, name='comment'),
    path('_<int:year>-<int:month>-<int:day>/', item_views.archive, name='archive'),
    path('_<int:year>/', item_views.archive, name='archive'),
    path('_<int:year>/<int:week>/', item_views.archive, name='archive'),
    path('<int:id>/', item_views.item, name='item'),
    path('<str:slug>/', page_views.page, name='page'),
    path('', item_views.index, name='index'),
]
